@@ -14,7 +14,7 @@ mcapply <- function(x, margin=c("all","var","unc","variates"), fun, ...)
 #Maybe \samp{"all"} (default) to apply the function on all values,
 #\samp{"var"} to apply the function on the variability dimension,
 #\samp{"unc"} to apply the function on the uncertainty dimension, or
-#\samp{"variates"} to apply the function on the variates.>>
+#\samp{"variates"} to apply the function on the variates. Watch out: do not use 'var' for 'variates'>>
 #{fun}<<The function to be applied.
 #When applied to a vector of length \samp{n}, \samp{fun} should return a vector of length \samp{n} or \samp{1}.>>
 #{\dots}<<Optionnal arguments to \samp{fun}.>>
@@ -45,6 +45,7 @@ mcapply <- function(x, margin=c("all","var","unc","variates"), fun, ...)
   if(!is.mcnode(x)) stop("x should be an mcnode")
 
   typen <- attr(x,"type")
+  oldoutm <- attr(x,which="outm")
   dimn <-  dim(x)
 
   dime <- switch(margin, "unc" = c(1,3), "var" = c(2,3), "all" = c(1,2,3), "variates" = c(1,2))
@@ -52,27 +53,34 @@ mcapply <- function(x, margin=c("all","var","unc","variates"), fun, ...)
 
   dat <- apply(x, dime, fun, ...)
   nl <- length(dat)
-  oneres <- nl == nlo        # fun give one scalar
-  if(nl != length(x) && !oneres) stop("fun(x) with length(x) = n should return a vector of length n or 1")
 
-  nsu <- ifelse(margin=="unc" && oneres,1,dimn[2])
-  nsv <- ifelse(margin=="var" && oneres,1,dimn[1])
-  nva <- ifelse(margin=="variates" && oneres,1,dimn[3])
+  if(nl == length(x)){		 # fun(n) give n scalar
+	if(margin == "unc") 			dat <- aperm(dat,c(2,1,3))
+	else if(margin == "variates") 	dat <- aperm(dat,c(2,3,1))
+	x[] <- dat
+	return(x)
+	}
+
+	if(nl != nlo) stop("fun(x) with length(x) = n should return a vector of length n or 1")
+  
+  nsu <- ifelse(margin=="unc", 1, dimn[2])
+  nsv <- ifelse(margin=="var", 1, dimn[1])
+  nva <- ifelse(margin=="variates", 1, dimn[3])
 
   if(typen=="0") ntype <- "0"
   
   else if(typen=="V"){
-    if(margin=="var" && oneres) ntype <- "0"
+    if(margin=="var") ntype <- "0"
     else ntype <- "V"}
 
   else if(typen=="U"){
-    if(margin=="unc" && oneres) ntype <- "0"
+    if(margin=="unc") ntype <- "0"
     else ntype <- "U"}
 
-  else if(margin=="unc" && oneres) ntype <- "V"
-  else if(margin=="var" && oneres) ntype <- "U"
+  else if(margin=="unc") ntype <- "V"
+  else if(margin=="var") ntype <- "U"
   else ntype <- "VU"
 
-  return(mcdata(as.vector(dat),type=ntype,nsv=nsv,nsu=nsu,nvariates=nva))
+ return(mcdata(as.vector(dat),type=ntype,nsv=nsv,nsu=nsu,nvariates=nva,outm=oldoutm))
 }
 
